==> haskell-adjunctions-4.3-11-armv7h.pkg.tar.xz: usr/share/haskell/haskell-adjunctions/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: adjunctions
version: 4.3
id: adjunctions-4.3-51e7d4a24d361113244a76d085504c45
key: adjun_4sJkfnsClao8vrjouiehAW
license: BSD3
copyright: Copyright (C) 2011-2014 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/adjunctions/
synopsis: Adjunctions and representable functors
description:
    Adjunctions and representable functors
category: Data Structures, Adjunctions
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Comonad.Representable.Store Control.Comonad.Trans.Adjoint
    Control.Monad.Representable.Reader
    Control.Monad.Representable.State Control.Monad.Trans.Adjoint
    Control.Monad.Trans.Contravariant.Adjoint Control.Monad.Trans.Conts
    Data.Functor.Adjunction Data.Functor.Contravariant.Adjunction
    Data.Functor.Contravariant.Rep Data.Functor.Rep
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/adjunctions-4.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/adjunctions-4.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/adjunctions-4.3
hs-libraries: HSadjunctions-4.3-4sJkfnsClao8vrjouiehAW
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    comonad-5-3b2e208311908bc5a9db1ceb26126917
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    contravariant-1.4-6e8bc7cb2457226c1a88750295477d07
    distributive-0.5.0.2-062a0a4262c71bd1a32922e0774f8a66
    free-4.12.4-f8dab736d0d811e91eb50084b5673f3a
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    profunctors-5.2-026a1eb9905bccdb097d36481584da83
    semigroupoids-5.0.1-ab1721c6c7a72801e6cd851407a313ad
    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
    void-0.7.1-5298c6b3a32576797627b9b87532f9cb
haddock-interfaces: /usr/share/doc/haskell-adjunctions/html/adjunctions.haddock
haddock-html: /usr/share/doc/haskell-adjunctions/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-adjunctions-4.3-12-armv7h.pkg.tar.xz: usr/share/haskell/haskell-adjunctions/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: adjunctions
version: 4.3
id: adjunctions-4.3-306c4088e5ded361b522da44159f8d3e
key: adjun_J1Fl4UpiLfnKCPhCzHUp0g
license: BSD3
copyright: Copyright (C) 2011-2014 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/adjunctions/
synopsis: Adjunctions and representable functors
description:
    Adjunctions and representable functors
category: Data Structures, Adjunctions
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Comonad.Representable.Store Control.Comonad.Trans.Adjoint
    Control.Monad.Representable.Reader
    Control.Monad.Representable.State Control.Monad.Trans.Adjoint
    Control.Monad.Trans.Contravariant.Adjoint Control.Monad.Trans.Conts
    Data.Functor.Adjunction Data.Functor.Contravariant.Adjunction
    Data.Functor.Contravariant.Rep Data.Functor.Rep
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/adjunctions-4.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/adjunctions-4.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/adjunctions-4.3
hs-libraries: HSadjunctions-4.3-J1Fl4UpiLfnKCPhCzHUp0g
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    comonad-5-eb230ef163a26fe6410daceeb92d736a
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    contravariant-1.4-1bd57c2540cd2864a467c8bf62a3fdb4
    distributive-0.5.0.2-062a0a4262c71bd1a32922e0774f8a66
    free-4.12.4-5e68614777ed20792496ad931a527625
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    profunctors-5.2-1a11bf84af8321e4318303d34ccac042
    semigroupoids-5.0.1-9020d584fd071e35efe756eb398e9c78
    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
    void-0.7.1-5298c6b3a32576797627b9b87532f9cb
haddock-interfaces: /usr/share/doc/haskell-adjunctions/html/adjunctions.haddock
haddock-html: /usr/share/doc/haskell-adjunctions/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
